@@ -9,9 +9,11 @@ var menu_list = [ [ 'About',      'index.html' ],
 var admin_menu_list = [ ['Admin', 'admin.html' ] ];
 
 
+var menu_attach_point;
+
 function make_menus( attach_point ) {
     var current_page = document.URL.match( /\/([^\/]*?)(\#.*)?$/ )[ 1 ];
-
+    menu_attach_point = attach_point;
     var buf = '';
     for( var i=0; i<menu_list.length; i++ ) {
 	if( current_page == menu_list[ i ][ 1 ] ) {
@@ -20,7 +22,6 @@ function make_menus( attach_point ) {
 	    buf += '<LI><A HREF="' + menu_list[ i ][ 1 ] + '">' + menu_list[ i ][ 0 ] + '</A></LI>';
 	}
     }
-
     if( $.yote.is_logged_in() && $.yote.get_login().is_root() ) {
 	for( var i=0; i<admin_menu_list.length; i++ ) {
 	    if( current_page == admin_menu_list[ i ][ 1 ] ) {
@@ -38,13 +39,22 @@ function make_menus( attach_point ) {
 function attach_login( args ) {
     var attachpoint         = args[ 'attachpoint' ];
     var message_attachpoint = args[ 'message_attachpoint' ];
-    var after_login_f       = args[ 'after_login' ]  || function(){};
-    var after_logout_f      = args[ 'after_logout' ] || function(){};
+    var a_login_f           = args[ 'after_login' ]  || function(){};
+    var a_logout_f          = args[ 'after_logout' ];
+    if( a_logout_f ) {
+	var after_logout_f = function() { make_menus( menu_attach_point ); a_logout_f(); }
+    } else {
+	after_logout_f = function() { make_menus( menu_attach_point ); }
+    }
+    if( a_logout_f ) {
+	var after_login_f = function() { make_menus( menu_attach_point ); a_login_f(); }
+    } else {
+	after_login_f = function() { make_menus( menu_attach_point ); }
+    }
 
     function msg( message, cls ) {
 	$( message_attachpoint ).empty();
 	if( message ) {
-	    console.log( '<nobr class="' + cls + '">' + message + '</nobr>' );
 	    $( message_attachpoint ).append( '<nobr class="' + cls + '">' + message + '</nobr>' );
 	}
 	after_logout_f();
